package com.yizhi.application.controller.manage;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;
import com.yizhi.application.entity.*;
import com.yizhi.application.orm.id.IdGenerator;
import com.yizhi.application.service.*;
import com.yizhi.assignment.application.vo.*;
import com.yizhi.assignment.application.vo.apivo.ApiAssignmentAnswerCheckVO;
import com.yizhi.assignment.application.vo.apivo.AssignmentTrainingProject;
import com.yizhi.core.application.context.ContextHolder;
import com.yizhi.core.application.context.RequestContext;
import com.yizhi.core.application.vo.DroolsVo;
import com.yizhi.system.application.system.remote.AccountClient;
import com.yizhi.util.application.domain.Response;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @Author: shengchenglong
 * @Date: 2018/3/7 13:59
 */
@Api(tags = "ManageAssignmentController", description = "后台管理作业接口")
@RestController(value = "ManageAssignmentControllerRemote")
@RequestMapping("/assignment")
public class ManageAssignmentController {

    private static final Logger logger = LoggerFactory.getLogger(ManageAssignmentController.class);

    @Autowired
    private AssignmentStudentService assignmentStudentService;
    @Autowired
    private AssignmentContentService assignmentcontentService;
    @Autowired
    private AssignmentService assignmentService;
    @Autowired
    private AssignmentFileService assignmentFileService;
    @Autowired
    private AssignmentAnswerService assignmentAnswerService;
    @Autowired
    private AssignmentAnswerFileService answerFileService;
    @Autowired
    private AssignmentAnswerSuggestionService assignmentAnswerSuggestionService;
    @Autowired
    private AssignmentAuditorService assignmentAuditorService;
    @Autowired
    private IdGenerator idGenerator;
    @Autowired
    private AssignmentGradeService assignmentGradeService;
    @Autowired
    private AssignmentPointService assignmentPointService;
    @Autowired
    private AccountClient accountClient;


    @ApiOperation(value = "生成作业id", notes = "生成作业id")
    @GetMapping("/setid")
    public Long setId() {
        return idGenerator.generate();
    }

    @ApiOperation(value = "作业新建接口", notes = "新建作业保存")
    @PostMapping("/save")
    public Boolean save(@ApiParam(name = "AssignmentVo", value = "作业新建入参对象", required = true) @RequestBody AssignmentSaveParamVo assignmentVo) {
        return assignmentService.save(assignmentVo);
    }

    @ApiOperation(value = "作业列表接口", notes = "分页查询作业列表")
    @GetMapping("/list")
    public Page<AssignmentListVO> list(@RequestParam(value = "currentTime", required = false) String currentTime,
                                       @RequestBody AssignmentListVoTo assignmentListVoTo) {
        List<AssignmentListVO> listVo = new ArrayList<AssignmentListVO>();
        Page<Assignment> page = assignmentService.assignmentList(currentTime, assignmentListVoTo);
        if (page != null) {
            List<Assignment> listAssignmentList = page.getRecords();
            for (int i = 0; i < listAssignmentList.size(); i++) {
                AssignmentListVO assignmentListVO = new AssignmentListVO();
                assignmentListVO.setId(listAssignmentList.get(i).getId()); // 作业id
                assignmentListVO.setSerialNum(listAssignmentList.get(i).getSerialNum()); // 作业序号
                assignmentListVO.setName(listAssignmentList.get(i).getName()); // 作业名字
                assignmentListVO.setTraingProjectId(listAssignmentList.get(i).getTrainingProjectId());
                assignmentListVO.setStatus(listAssignmentList.get(i).getStatus()); // 作业状态
                assignmentListVO.setEndDate(listAssignmentList.get(i).getFinishTime());
                assignmentListVO.setVisibleRange(listAssignmentList.get(i).getVisibleRange());
                assignmentListVO.setImage(listAssignmentList.get(i).getImage());

                assignmentListVO.setSubmitNum(assignmentAnswerService.submitNum(listAssignmentList.get(i).getId(),assignmentListVoTo.getAccountIds())); // 提交数量
                assignmentListVO.setNoRead(assignmentAnswerService.noRead(listAssignmentList.get(i).getId(),assignmentListVoTo.getAccountIds()));
                listVo.add(assignmentListVO);
            }

            Page<AssignmentListVO> page1 = new Page<AssignmentListVO>();
            page1.setTotal(page.getTotal());
            page1.setCurrent(assignmentListVoTo.getPageNo());
            page1.setSize(assignmentListVoTo.getPageSize());
            page1.setRecords(listVo);
            return page1;
        }
        return new Page<>();
    }


    @ApiOperation(value = "作业删除接口", notes = "作业删除")
    @PostMapping("/delete")
    public Boolean delete(@ApiParam(name = "AssignmentDeleteVO", value = "作业删除入参对象", required = true) @RequestBody AssignmentDeleteVO assignmentDelete) {
        return assignmentService.updateDelete(assignmentDelete);
    }


   /* @GetMapping("/content/find")
    @ApiOperation(value = "查看老师布置得作业的主键id查看作业具体内容", notes = "查看作业内容")
    public AssignmentSelectVo query(@ApiParam(name = "assignmentId", value = "作业id主键", required = true) @RequestParam(name = "assignmentId", required = true) Long assignmentId) {
        Assignment assignment = assignmentService.selectById(assignmentId);
        AssignmentContent content = assignmentcontentService.findByAssignmentId(assignmentId);
        List<AssignmentFile> assignmentFileList = assignmentFileService.listAssignmentFile(assignmentId);
        List<AssignmentGrade> listGrade = assignmentGradeService.getListAssignmentGrade(assignmentId);
        List<AssignmentPoint> listPoint = assignmentPointService.getListAssignmentPoint(assignmentId);
        //组装数据
        AssignmentSelectVo assignmentSelectVo = new AssignmentSelectVo();
        if (assignment != null) {
            assignmentSelectVo.setId(assignment.getId());
            assignmentSelectVo.setName(assignment.getName());
            assignmentSelectVo.setFinishTime(assignment.getFinishTime());
            assignmentSelectVo.setAmendable(assignment.getAmendable());
            assignmentSelectVo.setVisibleRange(assignment.getVisibleRange());
            assignmentSelectVo.setType(assignment.getType());
            assignmentSelectVo.setPassScore(assignment.getPassScore());
            assignmentSelectVo.setCount(assignment.getCount());
            assignmentSelectVo.setEnableRemind(assignment.getEnableRemind());

            assignmentSelectVo.setAnswerAttachmentNumMax(assignment.getAnswerAttachmentNumMax());
            assignmentSelectVo.setAnswerAttachmentNumMin(assignment.getAnswerAttachmentNumMin());
            assignmentSelectVo.setAnswerCharaterNumMax(assignment.getAnswerCharaterNumMax());
            assignmentSelectVo.setAnswerCharaterNumMin(assignment.getAnswerCharaterNumMin());
            assignmentSelectVo.setShowRes(assignment.getShowRes());
            assignmentSelectVo.setEnableExerciseBook(assignment.getEnableExerciseBook());
            assignmentSelectVo.setKeywords(assignment.getKeywords());
            assignmentSelectVo.setImage(assignment.getImage());
            assignmentSelectVo.setEnableTask(assignment.getEnableTask());
            assignmentSelectVo.setTaskStartDate(assignment.getTaskStartDate());
            assignmentSelectVo.setTaskEndDate(assignment.getTaskEndDate());
        }
        if (content != null) {
            assignmentSelectVo.setContent(content.getComment());
        }
        assignmentSelectVo.setAssignmentFiles(assignmentFileList);
        assignmentSelectVo.setListGrade(listGrade);
        assignmentSelectVo.setListPoint(listPoint);

        return assignmentSelectVo;
    }
*/

    /**
     * 问题：根据部门关键字查到这个站点下此部门的员工的id的list  accountIdList
     */

    @ApiOperation(value = "一个作业学员提交作业列表", notes = "学生作业列表")
    @GetMapping(value = "/answer/list")
    public Page<AssignmentReadListVO> assignmentAnswerList(
            @ApiParam(name = "assignmentId", value = "老师布置作业的id", required = true) @RequestParam(name = "assignmentId", required = true) Long assignmentId,
            @ApiParam(name = "state", value = "批阅状态（1:待阅，2：已阅,不传则为所有）", required = false) @RequestParam(name = "state", required = false) Integer state,
            @ApiParam(name = "name", value = "用户名/姓名/标签") @RequestParam(name = "name", required = false) String name,
            @ApiParam(name = "keywords", value = "部门关键字", required = false)
            @RequestParam(name = "keywords", required = false) String keywords,
            @RequestParam(name = "type", required = false,defaultValue = "1") Integer type,
            @ApiParam(name = "pageNo", value = "要跳转的页数", required = false) @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @ApiParam(name = "pageSize", value = "每页条数，默认：10", required = false) @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize) {

        RequestContext context = ContextHolder.get();
        Long accountId = context.getAccountId();
        logger.info("上下信息1：{}", JSON.toJSON(context));

        return assignmentAnswerService.assignmentAnswerList(keywords,name,assignmentId, accountId, state, type, pageNo, pageSize,null);
    }

    /**
     *  查询作业列表
     * @param answerListVo
     * @return
     */
    @PostMapping(value = "/manage/answer/list")
    public Page<AssignmentReadListVO> manageAssignmentAnswerList(@RequestBody AnswerListVo answerListVo) {

        RequestContext context = ContextHolder.get();
        Long accountId = context.getAccountId();
        logger.info("上下信息2：{}", JSON.toJSON(context));

        logger.info("传参数2：{}",JSON.toJSON(answerListVo));

        return assignmentAnswerService.assignmentAnswerList(answerListVo.getKeywords(),answerListVo.getName(),answerListVo.getAssignmentId(),
                accountId, answerListVo.getState(), answerListVo.getType(), answerListVo.getPageNo(), answerListVo.getPageSize(),answerListVo.getAccountIds());
    }


    /*@ApiOperation(value = "获取单个学生答案", notes = "单个作业信息", response = Response.class)
    @PostMapping("/marking/select")
    public ApiAssignmentAnswerCheckVO getAssignmentAnswer(@ApiParam(name = "AssignmentAnswerMarkingSelectVO", value = "获取单个学生作业信息入参", required = true) @RequestBody AssignmentAnswerMarkingSelectVO assignmentAnswerMarkingSelect) {
        RequestContext context = ContextHolder.get();
        Long accountId = context.getAccountId();
        List<AssignmentReadListVO> assignmentReadListVOList = assignmentAnswerService.getAssignmentAnswerIdList(assignmentAnswerMarkingSelect.getAccountIds(),assignmentAnswerMarkingSelect.getDepartment(), assignmentAnswerMarkingSelect.getName(), assignmentAnswerMarkingSelect.getAssignmentId(), accountId, assignmentAnswerMarkingSelect.getState(), assignmentAnswerMarkingSelect.getType()!=null ? assignmentAnswerMarkingSelect.getType() : 1);
       logger.info("返回列表：{}",JSON.toJSON(assignmentReadListVOList));

        ApiAssignmentAnswerCheckVO assignmentAnswerCheckVO = new ApiAssignmentAnswerCheckVO();
        if (!CollectionUtils.isEmpty(assignmentReadListVOList)) {
            List<Long> answerIds = assignmentReadListVOList.parallelStream().map(assignmentReadListVO -> {
                return assignmentReadListVO.getId();
            }).collect(Collectors.toList());
            assignmentAnswerCheckVO.setAnswerIds(answerIds);
            logger.info("返回的答案id的列表：{}",JSON.toJSON(answerIds));
        }

        Assignment assignment = assignmentService.selectById(assignmentAnswerMarkingSelect.getAssignmentId());
        AssignmentAnswer assignmentAnswer = assignmentAnswerService.selectAssignmentAnswerById(assignmentAnswerMarkingSelect.getAssignmentAnswerId());
        AssignmentAnswerSuggestion assignmentAnswerSuggestion = assignmentAnswerSuggestionService.selectSuggestionByAnswerId(assignmentAnswerMarkingSelect.getAssignmentAnswerId());
        //答案文件
        List<AssignmentAnswerFile> listAssignmentAnswerFile = answerFileService.listAssignmentAnswerFile(assignmentAnswerMarkingSelect.getAssignmentAnswerId());
        //反馈文件
        List<AssignmentAnswerFile> listAssignmentAnswerBackFile = answerFileService.listAssignmentAnswerBackFile(assignmentAnswerMarkingSelect.getAssignmentAnswerId());
        //上一份答案id   下一份答案id  根据时间排序
//        Long prevAnswerId = null;
//        Long nextAnswerId = null;
        *//*------------开始装数据---------------*//*
//        ApiAssignmentAnswerCheckVO assignmentAnswerCheckVO = new ApiAssignmentAnswerCheckVO();
        if (assignmentAnswer != null) {
            assignmentAnswerCheckVO.setRealName(assignmentAnswer.getRealName() != null ? assignmentAnswer.getRealName() : assignmentAnswer.getAccountName());
            assignmentAnswerCheckVO.setScore(assignmentAnswer.getScore());
            assignmentAnswerCheckVO.setContent(assignmentAnswer.getContent());
//            prevAnswerId = assignmentAnswerService.prevAnswerId(assignmentAnswer.getCreateTime(), assignmentAnswerMarkingSelect.getAssignmentId());
//            nextAnswerId = assignmentAnswerService.nextAnswerId(assignmentAnswer.getCreateTime(), assignmentAnswerMarkingSelect.getAssignmentId());
        }
        if (assignment != null) {
            assignmentAnswerCheckVO.setPassScore(assignment.getPassScore());
        }
        assignmentAnswerCheckVO.setListAssignmentAnswerFile(listAssignmentAnswerFile);
        if (assignmentAnswerSuggestion != null) {
            assignmentAnswerCheckVO.setSuggestion(assignmentAnswerSuggestion.getSuggestion());
        }
        assignmentAnswerCheckVO.setListAssignmentAnswerBackFile(listAssignmentAnswerBackFile);
//        assignmentAnswerCheckVO.setPrevAnswerId(prevAnswerId);
//        assignmentAnswerCheckVO.setNextAnswerId(nextAnswerId);

        *//**
         * 废弃字段-------????????????
         *//*
        List<String> fileUrl = new ArrayList<String>();
        fileUrl.add("废弃字段1--A");
        fileUrl.add("废弃字段1--B");
        fileUrl.add("废弃字段1--C");
        List<AssignmentGrade> gradesList = new ArrayList<AssignmentGrade>();
        AssignmentGrade g1 = new AssignmentGrade();
        AssignmentGrade g2 = new AssignmentGrade();
        gradesList.add(g1);
        gradesList.add(g2);
        String grade = "废弃字段3";
        assignmentAnswerCheckVO.setFileUrl(fileUrl);
        assignmentAnswerCheckVO.setGrades(gradesList);
        assignmentAnswerCheckVO.setGrade(grade);
        return assignmentAnswerCheckVO;
    }
*/

    @ApiOperation(value = "学员名单添加学员接口", notes = "添加学员", response = Response.class)
    @PostMapping("/student/add")
    public Boolean insert(@ApiParam(name = "listStudent", value = "添加学员", required = true) @RequestBody ListStudent listStudent) {
        return assignmentStudentService.add(listStudent);
    }

    /**
     * 添加关联学员，之前记录不删除
     *
     * @param assignmentStudents
     * @return
     */
    @PostMapping("/student/insert")
    public Boolean insertStudentRelation(@RequestBody List<AssignmentStudent> assignmentStudents) {
        return assignmentStudentService.insertStudentRelation(assignmentStudents);
    }

    @ApiOperation(value = "查看已关联的学员名单", notes = "已关联的学员名单")
    @GetMapping("/student/relation")
    public List<AssignmentStudent> studentRelation(@ApiParam(name = "assignmentId", value = "作业id主键", required = true) @RequestParam(name = "assignmentId", required = true) Long assignmentId) {
        return assignmentStudentService.relation(assignmentId);
    }


    @ApiOperation(value = "上架下架", notes = "上架下架")
    @PostMapping("/status/update")
    public Boolean update(@ApiParam(name = "assignmentUpAndDown", value = "上架下架", required = true) @RequestBody AssignmentUpAndDownVO assignmentUpAndDown) {
        return assignmentService.update(assignmentUpAndDown.getId(), assignmentUpAndDown.getStatus(), assignmentUpAndDown.getAccountId(), assignmentUpAndDown.getAccountName());
    }


    @ApiOperation(value = "作业批阅接口", notes = "老师批阅学生作业批阅保存")
    @PostMapping("/marking/save")
    public PointParamVO readSave(@ApiParam(name = "assignmentAnswerContentVO", value = "老师批阅学生作业批阅保存", required = true) @RequestBody AssignmentAnswerContentVO assignmentAnswerContentVO) {
        return assignmentService.assignmentReadOverByTeacher(assignmentAnswerContentVO);
    }


    @ApiOperation(value = "查看评阅人", notes = "查看评阅人")
    @GetMapping("/auditor/relation")
    public List<Long> getAuditor(@ApiParam(name = "assignmentId", value = "作业id", required = true) @RequestParam(name = "assignmentId", required = true) Long assignmentId) {
        return assignmentAuditorService.relationAuditor(assignmentId);
    }

    @ApiOperation(value = "设置评阅人", notes = "设置评阅人")
    @PostMapping("/auditor/insert")
    public Boolean setAuditor(@ApiParam(name = "ListAuditor", value = "ListAuditor") @RequestBody ListAuditor listAuditor) {
        return assignmentAuditorService.auditorInsert(listAuditor);
    }


    @ApiOperation(value = "导出作业批阅结果", notes = "导出作业批阅结果")
    @PostMapping("/export/suggetion/get")
    public AssignmentAnswerListExport exportResultExcel(@RequestBody DownloadAnswerVO vo) {
        Long assignmentId = vo.getAssignmentId();
        List<Long> answerIds = vo.getAnswerIds();
        return assignmentAnswerService.exportResultExcel(assignmentId, answerIds);
    }


    @ApiOperation(value = "导出未提交作业的名单", notes = "导出未提交作业的名单")
    @GetMapping("/export/unsubmit/get")
    public AssignmentQXVO getQXSubmitMessage(@ApiParam(value = "作业的Id", name = "作业的Id", required = true) @RequestParam(name = "assignmentId", required = true) Long assignmentId) {
        return assignmentService.getQXSubmitMessage(assignmentId);
    }


    @ApiOperation(value = "批量下载作业", notes = "批量下载作业")
    @PostMapping("/export/assignment/get")
    public List<AnswersDownVO> exportAssignmentZip(@RequestBody DownloadAnswerVO vo) {
        Long assignmentId = vo.getAssignmentId();
        List<Long> answerIds = vo.getAnswerIds();
        return assignmentAnswerService.getAnswerIdsDown(assignmentId, answerIds);
    }

    @ApiOperation(value = "下载学生作业", notes = "学生作业id列表")
    @GetMapping("/download/batch")
    public List<List<AssignmentAnswerFile>> getAssignmentAnswerList(@ApiParam(name = "ids", value = "学生作业主键", required = true) @RequestParam(name = "ids") List<Long> ids) {
        return answerFileService.selectAssignmentAnswerFileById(ids);
    }


    @ApiOperation(value = "根据账号id查询到此学员下的作业个数", notes = "根据账号id查询到此学员下的作业个数")
    @GetMapping("/select/assignmentNum/byAccountId")
    public Integer selectAssignmentNumByAcountId(@ApiParam(name = "accountId", value = "账号id", required = true) @RequestParam(name = "accountId", required = true) Long accountId) {
        return assignmentService.selectAssignmentNumByAccountId(accountId);
    }


    @ApiOperation(value = "可见范围导出", notes = "可见范围导出")
    @GetMapping("/export/visiblRange")
    public VisibleRangeExport vsibleRangeExport(@ApiParam(value = "作业的Id", name = "作业的Id", required = true) @RequestParam(name = "assignmentId", required = true) Long assignmentId) {
        return assignmentService.vsibleRangeExport(assignmentId);
    }

    @ApiOperation(value = "作业挂到培训项目")
    @PostMapping("/updateTrainingProject/byAssignmentId")
    public boolean updateTrainingProjectByAssignmentId(@RequestBody AssignmentTrainingProject atp) {

        logger.info(atp.toString());

        logger.info("培训项目的id{},培训项目的名字{},培训项目的作业集合{}", atp.getProjectId(), atp.getProjectName(), atp.getListAssignmentIds());


        return assignmentService.updateAssignmentTp(atp);
    }


    @GetMapping(value = "/by/new/server")
    public List<Map<String, Object>> getServerByCompanyIdAndIds(@RequestParam("companyId") Long companyId, @RequestParam(value = "ids", required = false) List<Long> ids) {
        return assignmentService.getServerByCompanyIdAndIds(companyId, ids);
    }


    @GetMapping(value = "/by/siteId/and/assignmentId/and/accountId")
    public List<Long> getListIdsBySiteIdAndAssignmentIdsAndAccountId(@RequestParam("sitId") Long siteId, @RequestParam("accountId") Long accountId, @RequestParam("ids") List<Long> ids) {
        return assignmentAnswerService.getListIdsBySiteIdAndAssignmentIdsAndAccountId(siteId, accountId, ids);
    }

    @GetMapping(value = "/delete/relation")
    public void deleteRelation(@RequestParam(name = "assignmentId", required = true) Long assignmentId) {
        assignmentService.delete(assignmentId);
    }

    /**
     * 经验池作业列表
     *
     * @param name
     * @param ids
     * @param pageNo
     * @param pageSize
     * @return
     */
    @PostMapping("/experiencePoolList")
    public Page<Map<String, Object>> experiencePoolList(@RequestParam(value = "name", required = false) String name,
                                                        @RequestBody List<Long> ids,
                                                        @RequestParam(value = "pageNo", required = false) Integer pageNo,
                                                        @RequestParam(value = "pageSize", required = false) Integer pageSize) {
        return assignmentService.experiencePoolList(name, ids, pageNo, pageSize);
    }

    /**
     * 查询作业完成的学员
     *
     * @param assignmentId
     * @return
     */
    @GetMapping("/finishAccountIds")
    public List<Long> getFinishedAccountIds(@RequestParam("assignmentId") Long assignmentId, @RequestParam("siteId") Long siteId, @RequestParam("companyId") Long companyId) {
        return assignmentAnswerService.getFinishedAccountIds(assignmentId, siteId, companyId);
    }

    /**
     * 查询作业分数
     *
     * @param assignmentId
     * @return
     */
    @GetMapping("/getScore")
    public Integer getScore(@RequestParam("assignmentId") Long assignmentId, @RequestParam("siteId") Long siteId, @RequestParam("companyId") Long companyId, @RequestParam("accountId") Long accountId) {
        return assignmentAnswerService.getScore(assignmentId, siteId, companyId, accountId);
    }

    @GetMapping("/visibleRange")
    public List<AssignmentStudent> VisibleRange(@RequestParam("assignmentId") Long assignmentId) {
        AssignmentStudent assignmentStudent = new AssignmentStudent();
        assignmentStudent.setAssignmentId(assignmentId);
        EntityWrapper<AssignmentStudent> wrapper = new EntityWrapper<AssignmentStudent>(assignmentStudent);
        return assignmentStudentService.selectList(wrapper);
    }

    @GetMapping("/get")
    public Assignment get(@RequestParam("assignmentId") Long assignmentId) {
        return assignmentService.selectById(assignmentId);
    }

    @PostMapping("/verifyVedio")
    public boolean verifyVedio(@RequestBody List<Long> answerFileIds) {
        int num = answerFileService.verifyVideo(answerFileIds);
        return num == answerFileIds.size();
    }

    @PostMapping("updateVedioTranscodeUrl")
    public boolean updateVedioTranscodeUrl(@RequestBody Map<String, String> map) {
        AssignmentAnswerFile file = new AssignmentAnswerFile();
        Long id = Long.valueOf(map.get("id"));
        file.setId(id);
        file.setVideoLd(map.get("ld"));
        file.setVideoHd(map.get("hd"));
        file.setVideoSd(map.get("sd"));

        return answerFileService.updateById(file);
    }

    @GetMapping("/getPageByDrools")
    Page<DroolsVo> getPageByDrools(@RequestParam("field") String field,
                                   @RequestParam(value = "value", required = false) String value,
                                   @RequestParam("pageNo") Integer pageNo,
                                   @RequestParam("pageSize") Integer pageSize) {
        Page<DroolsVo> page = new Page<>(pageNo, pageSize);
        return assignmentService.getPageByDrools(field, value, page);
    }
}

