package com.yizhi.application.controller.remote;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;
import com.yizhi.core.application.context.ContextHolder;
import com.yizhi.core.application.context.RequestContext;
import com.yizhi.application.entity.Assignment;
import com.yizhi.application.entity.AssignmentAnswer;
import com.yizhi.application.entity.AssignmentAnswerTipoff;
import com.yizhi.application.entity.AssignmentComment;
import com.yizhi.application.mapper.AssignmentAnswerMapper;
import com.yizhi.application.mapper.AssignmentAnswerTipoffMapper;
import com.yizhi.application.service.AssignmentExcelExporterService;
import com.yizhi.system.application.system.remote.AccountClient;
import com.yizhi.system.application.vo.AccountVO;
import com.yizhi.assignment.application.vo.TipoffAssignmentListVO;
import com.yizhi.assignment.application.vo.apivo.ApiAssignmentCommentVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.log4j.Log4j2;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang3.time.DateFormatUtils;
import org.apache.ibatis.session.RowBounds;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @ClassName AssignmentExpriceBookController
 * @Description TODO
 * @Author shengchenglong
 * @DATE 2019-10-22 11:15
 * @Version 1.0
 */
@Api("作业本--管理端")
@RestController(value = "ManageAssignmentExerciseBookControllerRemote")
@RequestMapping("/remote/manage/assignment/exerciseBook")
@Log4j2
public class ManageAssignmentExerciseBookController {

    @Autowired
    private AccountClient accountClient;
    @Autowired
    private AssignmentAnswerMapper assignmentAnswerMapper;
    @Autowired
    private AssignmentAnswerTipoffMapper assignmentAnswerTipoffMapper;
    @Autowired
    private AssignmentExcelExporterService assignmentExcelExporterService;


    @GetMapping("/answer/down")
    public boolean answerDown(@RequestParam("answerId") Long answerId, @RequestParam("isDown") Integer isDown) {
        AssignmentAnswer answer = new AssignmentAnswer();
        answer.setId(answerId);
        answer.setIsDown(isDown);
        return answer.updateById();
    }

    /**
     * 删除作业
     * @param answerId
     * @return
     */
    @GetMapping("/answer/delete")
    public boolean answerDelete(@RequestParam("answerId") Long answerId) {
        AssignmentAnswer answer = new AssignmentAnswer();
        answer.setId(answerId);
        answer.setDeleted(1);
        boolean b = answer.updateById();
        return b;
    }

    @GetMapping("/comment/page")
    @ApiOperation("评论列表")
    public Page<ApiAssignmentCommentVO> commentPage(
            @RequestParam("assignmentAnswerId") Long assignmentAnswerId,
            @ApiParam("要跳转的页数") @RequestParam(name = "pageNo", defaultValue = "1") int pageNo,
            @ApiParam("每页条数，默认：10") @RequestParam(name = "pageSize", defaultValue = "10") int pageSize
    ) {
        Page<AssignmentComment> page = new Page(pageNo, pageSize);

        AssignmentComment comment = new AssignmentComment();
//        comment.setAuditStatus(0);
        comment.setDeleted(0);
        comment.setCompanyId(ContextHolder.get().getCompanyId());
        comment.setSiteId(ContextHolder.get().getSiteId());
        comment.setAssignmentAnswerId(assignmentAnswerId);

        EntityWrapper<AssignmentComment> ew = new EntityWrapper<>(comment);
        ew.orderBy("create_time", false);
        page = comment.selectPage(page, ew);

        if (page != null && CollectionUtils.isNotEmpty(page.getRecords())) {
            List<ApiAssignmentCommentVO> vos = new ArrayList<>();
            page.getRecords().forEach(item -> {
                ApiAssignmentCommentVO vo = new ApiAssignmentCommentVO();
                vo.setCommentId(item.getId());
                vo.setContent(item.getContent());
                vo.setCreateTime(item.getCreateTime());
                vo.setAuditStatus(item.getAuditStatus());
                AccountVO accountVO = getAccount(item.getCreateById());
                if (accountVO != null) {
                    vo.setManageCommentator(accountVO.getName());
                    vo.setManageCommentatorFullName(accountVO.getFullName());
                }
                if (item.getParentCreateById() != null) {
                    accountVO = getAccount(item.getParentCreateById());
                    if (accountVO != null) {
                        vo.setParentCreateByName(StringUtils.isEmpty(accountVO.getFullName()) ? accountVO.getName() : accountVO.getFullName());
                    }
                }
                vos.add(vo);
            });

            Page<ApiAssignmentCommentVO> resultPage = new Page<>(pageNo, pageSize);
            resultPage.setTotal(page.getTotal());
            resultPage.setRecords(vos);
            return resultPage;
        }
        return new Page<>(pageNo, pageSize);
    }


    @GetMapping("/comment/delete")
    public boolean commentDelete(@RequestParam("commentId") Long commentId) {
        AssignmentComment comment = new AssignmentComment();
        comment.setId(commentId);
        comment.setDeleted(1);
        return comment.updateById();
    }

    @GetMapping("/comment/audit")
    public boolean commentDelete(@RequestParam("commentId") Long commentId, @RequestParam("auditStatus") Integer auditStatus) {
        AssignmentComment comment = new AssignmentComment();
        comment.setId(commentId);
        comment.setAuditStatus(auditStatus);
        return comment.updateById();
    }

    @GetMapping("/tipoff/answer/page")
    public Page<TipoffAssignmentListVO> tipoffAnswerPage(
            @RequestParam("assignmentName") String assignmentName,
            @ApiParam("要跳转的页数") @RequestParam(name = "pageNo", defaultValue = "1") int pageNo,
            @ApiParam("每页条数，默认：10") @RequestParam(name = "pageSize", defaultValue = "10") int pageSize) {
        Page<TipoffAssignmentListVO> tipoffAssignmentListVOPage = new Page<>(pageNo,pageSize);
        log.info("返回的值："+ JSON.toJSONString(tipoffAssignmentListVOPage));
        List<TipoffAssignmentListVO> vos = assignmentAnswerMapper.tipoffAssignmentList(assignmentName, ContextHolder.get(), new RowBounds(tipoffAssignmentListVOPage.getOffset(), tipoffAssignmentListVOPage.getLimit()));
        if (CollectionUtils.isNotEmpty(vos)) {
            Page<TipoffAssignmentListVO> page = new Page<>(pageNo, pageSize);
            AssignmentAnswerTipoff tipoff = new AssignmentAnswerTipoff();

            vos.forEach(item -> {
                item.setTipoffTime(assignmentAnswerTipoffMapper.getLastTipoffTime(item.getAnswerId()));
                Integer isNew = assignmentAnswerTipoffMapper.lastIsNew(item.getAnswerId());
                item.setHasNew(isNew == null ? false : isNew == 1);
                AccountVO accountVO = getAccount(item.getAccountId());
                if (accountVO != null) {
                    item.setUsername(accountVO.getName());
                    item.setFullName(accountVO.getFullName());
                }
            });

            page.setRecords(vos);
            page.setTotal(assignmentAnswerMapper.tipoffAssignmentListCount(assignmentName, ContextHolder.get()));
            return page;
        }
        return new Page<>(pageNo, pageSize);
    }

    @GetMapping("/tipoff/page")
    public Page<AssignmentAnswerTipoff> tipoffPage(
            @RequestParam("answerId") Long answerId,
            @ApiParam("要跳转的页数") @RequestParam(name = "pageNo", defaultValue = "1") int pageNo,
            @ApiParam("每页条数，默认：10") @RequestParam(name = "pageSize", defaultValue = "10") int pageSize) {
        AssignmentAnswerTipoff tipoff = new AssignmentAnswerTipoff();
        tipoff.setAssignmentAnswerId(answerId);
        tipoff.setStatus(0);
        EntityWrapper<AssignmentAnswerTipoff> ew = new EntityWrapper<>(tipoff);
        ew.orderBy("create_time", false);

        Page<AssignmentAnswerTipoff> page = new Page<>(pageNo, pageSize);
        page = tipoff.selectPage(page, ew);

        // 该作业查看过
        assignmentAnswerTipoffMapper.updateNotNew(answerId);

        return page;
    }

    @GetMapping("/tipoff/remove")
    public Boolean tipoffPage(
            @RequestParam("tipoffId") Long tipoffId) {
        AssignmentAnswerTipoff tipoff = new AssignmentAnswerTipoff();
        tipoff.setId(tipoffId);
        tipoff.setAuditorId(ContextHolder.get().getAccountId());
        tipoff.setAuditTime(new Date());
        tipoff.setStatus(1);
        return tipoff.updateById();
    }

    @GetMapping("/comment/export")
    public String commentExport(@RequestParam("answerId") Long answerId) {
        RequestContext context = ContextHolder.get();
        AssignmentAnswer answer = new AssignmentAnswer();
        answer.setId(answerId);
        answer = answer.selectById();

        if (answer != null) {
            Assignment assignment = new Assignment();
            assignment.setId(answer.getAssignmentId());
            assignment = assignment.selectById();
            if (assignment != null) {
                String fileNamePattern = answer.getCreateByName() + "的作业-"
                        + assignment.getName().replaceAll("/", ".") + "-评论记录" +
                        DateFormatUtils.format(new Date(), "yyyyMMDDHHmmss");
                return assignmentExcelExporterService.doExport(context, answerId, "ASSIGNMENT-COMMENT-EXPORT-", fileNamePattern);
            }
        }
        return null;
    }

    private AccountVO getAccount(long accountId) {
        AccountVO accountVO = accountClient.findById(accountId);
        return accountVO;
    }
}
