package com.yizhi.application.service;

import java.util.Date;
import java.util.List;

import com.baomidou.mybatisplus.plugins.Page;
import com.baomidou.mybatisplus.service.IService;
import com.yizhi.application.entity.AssignmentAnswer;
import com.yizhi.assignment.application.vo.AnswersDownVO;
import com.yizhi.assignment.application.vo.AssignmentAnswerExport;
import com.yizhi.assignment.application.vo.AssignmentAnswerListExport;
import com.yizhi.assignment.application.vo.AssignmentReadListVO;
import com.yizhi.assignment.application.vo.apivo.ApiAssignmentAnswerResultVo;
import com.yizhi.assignment.application.vo.apivo.ApiAssignmentAswerVO;
import com.yizhi.assignment.application.vo.apivo.ApiAssignmentDetailsVo;

/**
 * <p>
 * 学员对作业的对应关系
 服务类
 * </p>
 *
 * @author 王飞达123
 * @since 2018-03-08
 */
public interface AssignmentAnswerService extends IService<AssignmentAnswer> {
	
	
	


	/**
	 * 待阅读数量              管理端-----2018、09、08
	 * @param trainingProjectId
	 * @return
	 */
	Integer noRead(Long id,List<Long> accountIds);


	/**
	 * 提交数量                   管理端-----2018、09、08
	 * @param trainingProjectId
	 * @return
	 */
	Integer submitNum(Long id,List<Long> accountIds);

	
	
	  Integer canSubmitAssignmentAnswer(ApiAssignmentAswerVO vo);
	
	

    /**
     * 学生提交作业
     *
     * @return
     */
    Boolean submitAssignmentAnswer(ApiAssignmentAswerVO vo);

  
	/**
	 *
	 * @param assignmentId 老师布置作业id
	 * @param pageNo 当前页数
	 * @param pageSize 每一页存放的数据
	 * @return
	 */
    Page<AssignmentReadListVO> assignmentAnswerList(String keywords,String name,Long assignmentId,
                                                    Long accountId, Integer state, Integer type, Integer pageNo, Integer pageSize,List<Long> accountIds);

    /**
     * 回答的id 的列表
     * @param keywords
     * @param name
     * @param assignmentId
     * @param accountId
     * @param state
     * @param type
     * @return
     */
    List<AssignmentReadListVO> getAssignmentAnswerIdList(List<Long> accountIds,String keywords,String name,Long assignmentId,Long accountId, Integer state, Integer type);
	/**
	 * 学生列表总记录数目
	 * @param assignmentId
	 * @param state
	 * @param name
	 * @param accountIdList
	 * @param pageNo
	 * @param pageSize
	 * @return
	 */
	Integer assignmentAnswerListNum(Long assignmentId, Integer state, String name, List<Long> accountIdList, Integer pageNo, Integer pageSize);
	/**
	 *
	 * @param id 答案id
	 * @return 返回答案实体
	 */
	AssignmentAnswer selectAssignmentAnswerById(Long id);
	
	/**
	 * 老师批阅学生提交的答案
	 * @param assignmentAnswer
	 * @return
	 */
	Boolean insertTeacherToStudent(AssignmentAnswer assignmentAnswer);
	
	/**
	 * 批量下载作业
	 * @param id
	 * @return
	 */
	List<AssignmentAnswerExport> listExport(List<Long> answerIds);

	
	/**
	 * 下一份作业id
	 * @param assignmentAnswerId
	 * @return
	 */
	Long nextAnswerId(Date createTime,Long assignmentId);
	
	/**
	 * 上一份作业id
	 * @param assignmentAnswerId
	 * @return
	 */
	Long prevAnswerId(Date createTime,Long assignmentId);
	
	/**
	 * 
	 * @param assignmentId
	 * @param accountId
	 * @return
	 */
	List<AssignmentAnswer> getAssignmentAnswer(Long assignmentId,Long accountId);
	
	/**
	 * 根据账号id和作业id 判断是否已提交
	 * @param accountId
	 * @param assignmentId
	 * @return
	 */
	AssignmentAnswer isHaveAnswerByAccountIdAndAssignmentId(Long accountId,Long assignmentId);
	
	
	
/*	*//**
	 * @param answerId
	 * @return
	 *//*
	ApiSuggestionVo getMyAnswerDetailsByAssignmentId(Long assignmentId,Long accountId);*/
	
	
	
	/**
	 * 根据条件导出excel表格
	 * @return
	 */
	AssignmentAnswerListExport exportResultExcel(Long assignmentId,List<Long> answerIds);
	
	
	/**
	 * 根据answerIds 查找到条件是本地上传的answerIds
	 * @param answerIds
	 * @return
	 */
	List<AnswersDownVO> getAnswerIdsDown(Long assignmentId,List<Long> answerIds);
	
	/**
	 * 根据作业id和账号id 找到答案
	 * @param assignmentId
	 * @param accountId
	 * @return
	 */
	AssignmentAnswer getAssignmentAnswerByAccountAssignmentIdAndAccountId(Long assignmentId,Long accountId);
	
	
	
	
	
	
	
	/**
	 * 作业的答案页面
	 * @param assignmentId
	 * @param accountId
	 * @return
	 */
	ApiAssignmentAnswerResultVo getAnswerList(Long assignmentId,Long accountId);
	
	
	
	
	/**
	 * 获取作业信息（包含已经提交的文件）
	 *
	 * @param assignmentId
	 * @return
	 */
	ApiAssignmentDetailsVo toAssignment(Long assignmentId,Long answerId,Long accountId);
	
	
	/**
	 * 2018-09-07
	 * 根据作业Id和账号Id查找到此人这个作业提交了多少份
	 * @param assignmentId
	 * @param accountId
	 * @return
	 */
	List<AssignmentAnswer> listAssignmentAnswerByAssignmentIdAndAccountId(Long assignmentId,Long accountId);

    /**
     * 查询已经答题的次数
     * @param assignmentId
     * @param accountId
     * @return
     */
	Integer getAssignmentAnswerCount(Long assignmentId,Long accountId);
	
	
	
	List<Long> getListIdsBySiteIdAndAssignmentIdsAndAccountId(Long siteId,Long accountId,List<Long> ids);
	
	String getStudentAnswerZipByAnswerId(Long assignmentId,Long answerId);
	
	List<Long> getFinishedAccountIds(Long assignmentId,Long siteId,Long companyId);
	
	Integer getScore(Long assignmentId,Long siteId,Long companyId,Long accountId);

}
