package com.yizhi.application.service;

import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.yizhi.core.application.context.RequestContext;
import com.yizhi.core.application.context.TaskContext;
import com.yizhi.application.entity.AssignmentComment;
import com.yizhi.core.application.file.domain.FileInfo;
import com.yizhi.core.application.file.domain.Template;
import com.yizhi.core.application.file.domain.TemplateColumn;
import com.yizhi.core.application.file.exp.ExcelExportor;
import com.yizhi.core.application.log.LogEventPublisher;
import com.yizhi.application.orm.id.IdGenerator;
import com.yizhi.system.application.system.remote.AccountClient;
import com.yizhi.core.application.task.TaskExecutor;
import com.yizhi.system.application.vo.AccountVO;
import com.yizhi.assignment.application.vo.apivo.ApiAssignmentCommentVO;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang3.time.DateFormatUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @ClassName AssignmentExcelExporter
 * @Description TODO
 * @Author shengchenglong
 * @DATE 2019-10-25 10:50
 * @Version 1.0
 */
@Component
public class AssignmentExcelExporterService {

    private static final Logger LOGGER = LoggerFactory.getLogger(AssignmentExcelExporterService.class);

    @Autowired
    private TaskExecutor taskExecutor;
    @Autowired
    private IdGenerator idGenerator;
    @Autowired
    private LogEventPublisher publisher;
    @Autowired
    private AccountClient accountClient;

    public String doExport(RequestContext requestContext, Long answerId, String taskSerialNoPrefix, String fileNamePattern) {
        Date now = new Date();
        String serialNo = taskSerialNoPrefix + DateFormatUtils.format(now, "yyyyMMdd HH:mm:ss");
        TaskContext taskContext = new TaskContext(idGenerator.generate(), serialNo, fileNamePattern, requestContext.getAccountId(),
                now, requestContext.getSiteId(), requestContext.getCompanyId());
        AssignmentExcelExporter accountExporter = new AssignmentExcelExporter<>(null, null, answerId, requestContext, fileNamePattern);
        accountExporter.bindContext(taskContext);
        accountExporter.bindPublisher(publisher);
        taskExecutor.asynExecute(accountExporter);
        LOGGER.info("开始导出异步任务：{}", taskSerialNoPrefix);
        return serialNo;
    }

    private List<ApiAssignmentCommentVO> getData(RequestContext requestContext, Long answerId) {
        AssignmentComment comment = new AssignmentComment();
        comment.setSiteId(requestContext.getSiteId());
        comment.setCompanyId(requestContext.getCompanyId());
        comment.setAssignmentAnswerId(answerId);
        comment.setDeleted(0);

        EntityWrapper<AssignmentComment> ew = new EntityWrapper<>(comment);
        ew.orderBy("create_time", false);
        List<AssignmentComment> comments = comment.selectList(ew);

        if (CollectionUtils.isNotEmpty(comments)) {
            List<ApiAssignmentCommentVO> vos = new ArrayList<>();
            comments.forEach(item -> {
                ApiAssignmentCommentVO vo = new ApiAssignmentCommentVO();
                vo.setCommentId(item.getId());
                vo.setContent(item.getContent());
                vo.setCreateTime(item.getCreateTime());
                vo.setAuditStatus(item.getAuditStatus());
                AccountVO accountVO = getAccount(item.getCreateById());
                if (accountVO != null) {
                    vo.setManageCommentator(accountVO.getName());
                    vo.setManageCommentatorFullName(accountVO.getFullName());
                }
                if (item.getParentCreateById() != null) {
                    accountVO = getAccount(item.getParentCreateById());
                    if (accountVO != null) {
                        vo.setParentCreateByName(StringUtils.isEmpty(accountVO.getFullName()) ? accountVO.getName() : accountVO.getFullName());
                    }
                }
                vos.add(vo);
            });
            return vos;
        }
        return null;
    }

    private AccountVO getAccount(long accountId) {
        AccountVO accountVO = accountClient.findById(accountId);
        return accountVO;
    }


    private Template buildTemplate(RequestContext requestContext, String fileNamePattern) {
        Template template = new Template();
        List<TemplateColumn> columns = new ArrayList<>();
        columns.add(new TemplateColumn("manageCommentator", "评论人/回复人", 1));
        columns.add(new TemplateColumn("manageCommentatorFullName", "姓名", 2));
        columns.add(new TemplateColumn("parentCreateByName", "评论对象", 3));
        columns.add(new TemplateColumn("content", "评论内容", 4));
        columns.add(new TemplateColumn("createTime", "提交时间", 5));
        columns.add(new TemplateColumn("auditStatusStr", "状态", 6));

        template.setColumns(columns);
        template.setFileName(fileNamePattern + DateFormatUtils.format(new Date(), "yyyyMMdd") + ".xls");
        template.setBrowserExport(false);
        return template;
    }

    /**
     * 导出实现
     *
     * @param <T>
     */
    class AssignmentExcelExporter<T> extends ExcelExportor<T> {

        private RequestContext requestContext;
        private String fileNamePattern;
        private Long answerId;

        public AssignmentExcelExporter(Template template, List<T> data, Long answerId, RequestContext requestContext, String fileNamePattern) {
            super(template, data);
            this.requestContext = requestContext;
            this.fileNamePattern = fileNamePattern;
            this.answerId = answerId;
        }

        private void beforeRender() {
            Template template = buildTemplate(requestContext, fileNamePattern);
            this.template = template;
            this.data = (List<T>) getData(requestContext, answerId);
        }

        @Override
        public FileInfo render() {
            beforeRender();
            return super.render();
        }
    }

}
