package com.yizhi.application.service.impl;

import java.util.Date;
import java.util.List;

import com.yizhi.application.entity.AssignmentStudent;
import com.yizhi.application.mapper.AssignmentStudentMapper;
import com.yizhi.application.service.AssignmentStudentService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.toolkit.CollectionUtils;
import com.yizhi.application.orm.id.IdGenerator;
import com.yizhi.assignment.application.vo.ListStudent;
import com.yizhi.assignment.application.vo.StudentVo;

/**
 * <p>
 * 老师布置作业和学生进行关联。
 * 多对多的关系。
 * 一个老师布置的作业有多个学生做。 服务实现类
 * </p>
 *
 * @author 王飞达123
 * @since 2018-03-08
 */
@Transactional
@Service
public class AssignmentStudentServiceImpl extends ServiceImpl<AssignmentStudentMapper, AssignmentStudent> implements AssignmentStudentService {

    private Logger logger = LoggerFactory.getLogger(AssignmentStudentServiceImpl.class);

    @Autowired
    private IdGenerator idGenerator;


    @Autowired
    private AssignmentStudentService assignmentStudentService;

    @Autowired
    private AssignmentStudentMapper assignmentStudentMapper;


    /**
     * 学员添加
     */
    @Transactional
    public Boolean add(ListStudent listStudent) {
        //先删除  2再添加
        assignmentStudentService.deleteRelation(listStudent.getAssignmentId());

        Date date = new Date();
        Long createId = listStudent.getAccountId();
        String name = listStudent.getAccountName();
        Long assignmentId = listStudent.getAssignmentId();
        List<StudentVo> listAccountId = listStudent.getListAccountId();
        AssignmentStudent assignmentStudent = null;
        if (!CollectionUtils.isEmpty(listAccountId) && listAccountId.size() > 0) {
            for (int i = 0; i < listAccountId.size(); i++) {
                assignmentStudent = new AssignmentStudent();
                assignmentStudent.setId(idGenerator.generate());
                assignmentStudent.setAssignmentId(assignmentId);
                assignmentStudent.setAccountId(listAccountId.get(i).getAdoId());
                assignmentStudent.setType(listAccountId.get(i).getType());
                assignmentStudent.setCreateById(createId);
                assignmentStudent.setCreateByName(name);
                assignmentStudent.setCreateTime(date);
                this.insert(assignmentStudent);
            }
        }
        return true;
    }

    /**
     * 学员添加，之前记录不删除
     *
     * @param assignmentStudents
     * @return
     */
    @Override
    @Transactional
    public Boolean insertStudentRelation(List<AssignmentStudent> assignmentStudents) {
        if (!CollectionUtils.isEmpty(assignmentStudents)) {
            Long assignmentId = assignmentStudents.get(0).getAssignmentId();
            AssignmentStudent assignmentStudent = new AssignmentStudent();
            assignmentStudent.setAssignmentId(assignmentId);
            EntityWrapper<AssignmentStudent> entityWrapper = new EntityWrapper<AssignmentStudent>(assignmentStudent);
            this.baseMapper.delete(entityWrapper);
            for (AssignmentStudent assignmentStudent1 : assignmentStudents) {
                assignmentStudent1.setId(idGenerator.generate());
            }
            return this.insertBatch(assignmentStudents);
        } else {
            logger.error("列表为空");
            return Boolean.FALSE;
        }
    }

    /**
     * 已经关联的学员名单
     */
    @Override
    public List<AssignmentStudent> relation(Long assignmentId) {
        // TODO Auto-generated method stub
        AssignmentStudent assignmentStudent = new AssignmentStudent();
        assignmentStudent.setAssignmentId(assignmentId);
        EntityWrapper<AssignmentStudent> wrapper = new EntityWrapper<AssignmentStudent>(assignmentStudent);
        return this.selectList(wrapper);
    }

    /**
     * 已关联的总学员名单数量
     */

    @Override
    public Integer sumNum(Long assignmentId) {
        // TODO Auto-generated method stub
        AssignmentStudent assignmentStudent = new AssignmentStudent();
        assignmentStudent.setAssignmentId(assignmentId);
        EntityWrapper<AssignmentStudent> wrapper = new EntityWrapper<AssignmentStudent>(assignmentStudent);
        return this.selectCount(wrapper);
    }

    @Override
    public Boolean deleteRelation(Long assignmentId) {
        // TODO Auto-generated method stub
        AssignmentStudent assignmentStudent = new AssignmentStudent();
        assignmentStudent.setAssignmentId(assignmentId);
        EntityWrapper<AssignmentStudent> wrapper = new EntityWrapper<AssignmentStudent>(assignmentStudent);
        return this.delete(wrapper);
    }

    @Override
    public Integer getAssignmentNumByAccountId(List<Long> relationIds, Long siteId, Long accountId) {
        // TODO Auto-generated method stub
        return assignmentStudentMapper.myAllListNum(relationIds, siteId);
    }
}
